@@ -9,8 +9,9 @@ import $ from "jquery";
 document.addEventListener("DOMContentLoaded", function () {
     document.getElementById("nav-icon").addEventListener("click", function () {
         $(this).toggleClass('open');
-        $("#sitewrapper").toggleClass("pushedright");
-        $("#sidebar").toggleClass("open");
-        $("header").toggleClass("pushedright");
-    })
+
+        $('#sidebar').sidebar('setting', 'onHide', function (){
+          $('#nav-icon').removeClass('open');
+        }).sidebar('toggle');
+    });
 });
